Compositions
============

Subclasses of `Core` `Composition` that implement specialized operations.

.. toctree::
   :maxdepth: 1

   AutodiffComposition
   CompositionFunctionApproximator
   ParameterEstimationComposition
   EMComposition

